@@ -30,7 +30,7 @@ class QXmlStreamWriter;
 class ElementItem: public QStandardItem
 {
     public:
-        explicit ElementItem(const ThemeElement &el);
+        explicit ElementItem(const QString& text, const ThemeElement &el);
         void writeElement(QXmlStreamWriter *stream);
         QString checkMessage() const {return m_checkMessage;};
         bool check(int index);
